{% extends "wagtailadmin/base.html" %}
{% load embed_video_tags wagtailimages_tags %}
{% load i18n %}
{% block titletag %}{% trans "Delete video" %}{% endblock %}
{% block bodyclass %}menu-embed-videos{% endblock %}

{% block content %}
    {% trans "Delete video" as del_str %}
    {% include "wagtailadmin/shared/header.html" with title=del_str icon="media" %}

    <div class="row row-flush nice-padding">
        <div class="col6">
            {% if embed_video.thumbnail %}
                {% image embed_video.thumbnail max-800x600 %}
            {% else %}
                {% video embed_video.url as my_video %}
                    <img src="{{ my_video.thumbnail }}">
                {% endvideo %}
            {% endif %}
        </div>
        <div class="col6">
            <p>{% trans "Are you sure you want to delete this video?" %}</p>
            <form action="{% url 'wagtail_embed_videos_delete_embed_video' embed_video.id %}" method="POST">
                {% csrf_token %}
                <input type="submit" value="{% trans 'Yes, delete' %}" class="serious" />
            </form>
        </div>
    </div>
{% endblock %}
