{% extends "wagtailadmin/base.html" %}
{% load i18n %}

{% block titletag %}{% trans "Videos" %}{% endblock %}
{% block bodyclass %}menu-embed-videos{% endblock %}
{% block extra_js %}
    <script>
        window.headerSearch = {
            url: "{% url 'wagtail_embed_videos_index' %}",
            termInput: "#id_q",
            targetOutput: "#embed-video-results"
        }
    </script>
{% endblock %}

{% block content %}
    {% trans "Videos" as ev_str %}
    {% trans "Add a video" as add_ev_str %}
    {% include "wagtailadmin/shared/header.html" with title=ev_str add_link="wagtail_embed_videos_add_embed_video" icon="media" add_text=add_ev_str search_url="wagtail_embed_videos_index" %}

    <div class="nice-padding">
        <div id="embed-video-results">
            {% include "wagtail_embed_videos/embed_videos/results.html" %}
        </div>
    </div>

{% endblock %}
